Contributing
============

Submit bugs and issues to the   `GitHub repository <https://github.com/tzicatl/lfs-compropago>`_.

AUTHORS
=======

If you have contributed to this package feel free to add your name and email to the list.

* Noe Nieto <nnieto@noenieto.com>

